/*
	An example of an NPC whose dialogue starts with a Tell List,
	followed by a quest which blocks dialogue progress until the quest is completed.
*/

#include "TellsLink.dm"

world
	New()
		..()
		new/mob/npc/Quest(locate(5, 5, 1))

mob/player
	var
		killed_stuff = FALSE

	verb
		kill_stuff()
			// Intense combat system right here.
			killed_stuff = TRUE
			src << "You kill some stuff..."

	proc
		HasKilledEnoughStuff()
			// Quest progress check.
			return killed_stuff

mob/npc/Quest
	DialogueStart(mob/player/player)
		// Start dialogue with this chain.
		return new.dialogue_chain

	dialogue_chain
		parent_type = /dialogue/chain

		New()
			// Start the chain at the Intro Link.
			..(new.links/Intro)

		links
			parent_type = /dialogue/chain/link

			Intro
				parent_type = /dialogue/chain/link/tells

				// Initialize the tell list with this list of lines.
				tells = list(
					"Hello",
					"there,",
					"dude.",
					"Kill some stuff for me bro",
				)

				After()
					// After the Tells are complete, move on to the Quest intro.
					return new.InProgress

			InProgress
				Action(mob/npc/npc, mob/player/player)
					npc.Tell(player, "Have you killed enough stuff for me yet bro")

				Next(mob/npc/npc, mob/player/player)
					// If player killed enough stuff, then go to Complete, otherwise repeat.
					return player.HasKilledEnoughStuff() ? new.Complete : src

			Complete
				parent_type = /dialogue/chain/link/tells

				tells = list(
					"O cool you killed enough stuff",
					"Thx for killin stuff bro",
				)
